@@ -73,9 +73,10 @@ imp_binary_multi <- function(y_imp,
 
   YZ <- data.frame(target = ph, Z)
   #remove intercept variable
-  YZ <- YZ[, get_type(YZ) != "intercept", drop = FALSE]
+  YZ <- YZ[, apply(YZ, 2, get_type) != "intercept", drop = FALSE]
 
-  Z2 <- stats::model.matrix(stats::lm("target ~ 1 + .", data = YZ))
+  Z2 <- stats::model.matrix(stats::glm("target ~ 1 + .", data = YZ,
+                                       family = stats::binomial(link = "logit")))
   # ----------- set up a maximal model matrix with all possible relevant (dummy) variables -----
   # In the imputation model only actually relevant (dummy) variables shall be present.
   # THis is done by setting up a mirror of the initial model matrix.
@@ -174,8 +175,14 @@ imp_binary_multi <- function(y_imp,
     if(length(most_insignificant) == 0){
       check <- FALSE
     }else{
-      #get and update the model matrix:
-      X_model_matrix_1_sub <- X_model_matrix_1_sub[, -most_insignificant, drop = FALSE]
+
+      #.. drop the insignificant variable from the model.matrix, but only if at least 1 variable remains
+      tmp_MM <- stats::model.matrix(reg_1_sub)[, -most_insignificant, drop = FALSE]
+      if(ncol(tmp_MM) == 0){
+        check <- FALSE
+      }else{
+        X_model_matrix_1_sub <- tmp_MM
+      }
     }
   }
 
